#[non_exhaustive]pub enum SendDatagramError {
#[non_exhaustive] NotAvailable,
#[non_exhaustive] TooLarge,
#[non_exhaustive] ConnectionError(ConnectionError),
}Expand description
Types of errors when sending a datagram.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]NotAvailable
The peer is not accepting datagrams on the quic layer
This can be because the peer does not support it or disabled it or any other reason.
#[non_exhaustive]TooLarge
The datagram is too large to send
#[non_exhaustive]ConnectionError(ConnectionError)
Connection error